@@ -166,6 +166,12 @@ pub unsafe extern "C" fn PyInit_ormsgpack() -> *mut PyObject {
         "OPT_OMIT_MICROSECONDS\0",
         opt::OMIT_MICROSECONDS
     );
+    opt!(
+        exported_objects,
+        mptr,
+        "OPT_PASSTHROUGH_BIG_INT\0",
+        opt::PASSTHROUGH_BIG_INT
+    );
     opt!(
         exported_objects,
         mptr,
@@ -196,6 +202,12 @@ pub unsafe extern "C" fn PyInit_ormsgpack() -> *mut PyObject {
         "OPT_SERIALIZE_PYDANTIC\0",
         opt::SERIALIZE_PYDANTIC
     );
+    opt!(
+        exported_objects,
+        mptr,
+        "OPT_PASSTHROUGH_TUPLE\0",
+        opt::PASSTHROUGH_TUPLE
+    );
     opt!(exported_objects, mptr, "OPT_UTC_Z\0", opt::UTC_Z);
 
     typeref::init_typerefs();
@@ -262,12 +274,11 @@ pub unsafe extern "C" fn unpackb(
 
     let num_args = pyo3::ffi::PyVectorcall_NARGS(nargs as usize);
     if unlikely!(num_args != 1) {
-        let msg;
-        if num_args > 1 {
-            msg = Cow::Borrowed("unpackb() accepts only 1 positional argument");
+        let msg = if num_args > 1 {
+            Cow::Borrowed("unpackb() accepts only 1 positional argument")
         } else {
-            msg = Cow::Borrowed("unpackb() missing 1 required positional argument: 'obj'")
-        }
+            Cow::Borrowed("unpackb() missing 1 required positional argument: 'obj'")
+        };
         return raise_unpackb_exception(deserialize::DeserializeError::new(msg));
     }
     if !kwnames.is_null() {
@@ -288,13 +299,15 @@ pub unsafe extern "C" fn unpackb(
 
     let mut optsbits: i32 = 0;
     if let Some(opts) = optsptr {
-        if (*opts.as_ptr()).ob_type != typeref::INT_TYPE {
-            return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
-                "Invalid opts",
-            )));
-        }
-        optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
-        if !(0..=opt::MAX_UNPACKB_OPT).contains(&optsbits) {
+        let ob_type = (*opts.as_ptr()).ob_type;
+        if ob_type == typeref::INT_TYPE {
+            optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
+            if !(0..=opt::MAX_UNPACKB_OPT).contains(&optsbits) {
+                return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
+                    "Invalid opts",
+                )));
+            }
+        } else if ob_type != typeref::NONE_TYPE {
             return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
                 "Invalid opts",
             )));
@@ -350,13 +363,15 @@ pub unsafe extern "C" fn unpackb(
 
     let mut optsbits: i32 = 0;
     if let Some(opts) = optsptr {
-        if (*opts.as_ptr()).ob_type != typeref::INT_TYPE {
-            return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
-                "Invalid opts",
-            )));
-        }
-        optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
-        if !(0..=opt::MAX_UNPACKB_OPT).contains(&optsbits) {
+        let ob_type = (*opts.as_ptr()).ob_type;
+        if ob_type == typeref::INT_TYPE {
+            optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
+            if !(0..=opt::MAX_UNPACKB_OPT).contains(&optsbits) {
+                return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
+                    "Invalid opts",
+                )));
+            }
+        } else if ob_type != typeref::NONE_TYPE {
             return raise_unpackb_exception(deserialize::DeserializeError::new(Cow::Borrowed(
                 "Invalid opts",
             )));
@@ -422,11 +437,13 @@ pub unsafe extern "C" fn packb(
 
     let mut optsbits: i32 = 0;
     if let Some(opts) = optsptr {
-        if (*opts.as_ptr()).ob_type != typeref::INT_TYPE {
-            return raise_packb_exception(Cow::Borrowed("Invalid opts"));
-        }
-        optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
-        if !(0..=opt::MAX_PACKB_OPT).contains(&optsbits) {
+        let ob_type = (*opts.as_ptr()).ob_type;
+        if ob_type == typeref::INT_TYPE {
+            optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
+            if !(0..=opt::MAX_PACKB_OPT).contains(&optsbits) {
+                return raise_packb_exception(Cow::Borrowed("Invalid opts"));
+            }
+        } else if ob_type != typeref::NONE_TYPE {
             return raise_packb_exception(Cow::Borrowed("Invalid opts"));
         }
     }
@@ -495,11 +512,13 @@ pub unsafe extern "C" fn packb(
 
     let mut optsbits: i32 = 0;
     if let Some(opts) = optsptr {
-        if (*opts.as_ptr()).ob_type != typeref::INT_TYPE {
-            return raise_packb_exception(Cow::Borrowed("Invalid opts"));
-        }
-        optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
-        if !(0..=opt::MAX_PACKB_OPT).contains(&optsbits) {
+        let ob_type = (*opts.as_ptr()).ob_type;
+        if ob_type == typeref::INT_TYPE {
+            optsbits = PyLong_AsLong(optsptr.unwrap().as_ptr()) as i32;
+            if !(0..=opt::MAX_PACKB_OPT).contains(&optsbits) {
+                return raise_packb_exception(Cow::Borrowed("Invalid opts"));
+            }
+        } else if ob_type != typeref::NONE_TYPE {
             return raise_packb_exception(Cow::Borrowed("Invalid opts"));
         }
     }
